@@ -2612,6 +2612,11 @@ func TestWildcard(t *testing.T) {
 			call:           "start-foo",
 			expectedOutput: "Starting foo\n",
 		},
+		{
+			name:           "alias",
+			call:           "s-foo",
+			expectedOutput: "Starting foo\n",
+		},
 		{
 			name:           "matches exactly",
 			call:           "matches-exactly-*",
